MethodChannelPhPickerViewController class

An implementation of PhPickerViewControllerPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(List<String> ids) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pick({Map<String, List<String>>? filter, int? selectionLimit, PHPickerAssetRepresentationMode? preferredAssetRepresentationMode, PHPickerSelection? selection, String? fileRepresentation, bool? appendLiveVideos}) → Future<List<PHPickerResult>?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited